@@ -26,7 +26,7 @@
 #define __NSExpression_h_GNUSTEP_BASE_INCLUDE
 #import	<GNUstepBase/GSVersionMacros.h>
 
-#if	OS_API_VERSION(100400, GS_API_LATEST)
+#if	OS_API_VERSION(MAC_OS_X_VERSION_10_4, GS_API_LATEST)
 
 #import	<Foundation/NSObject.h>
 
@@ -38,18 +38,21 @@ extern "C" {
 @class NSMutableDictionary;
 @class NSString;
 
-typedef enum _NSExpressionType
+enum
 {
   NSConstantValueExpressionType=0,
   NSEvaluatedObjectExpressionType,
   NSVariableExpressionType,
   NSKeyPathExpressionType,
   NSFunctionExpressionType
-} NSExpressionType;
+};
+typedef NSUInteger NSExpressionType;
 
 @interface NSExpression : NSObject <NSCoding, NSCopying>
 {
+#if	GS_EXPOSE(NSExpression)
   NSExpressionType _type;
+#endif
 }
 
 + (NSExpression *) expressionForConstantValue: (id)obj;
